# Generated by Django 2.0.4 on 2018-05-16 18:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tradukoj', '0002_auto_20180516_0958'),
    ]

    operations = [
        migrations.AddField(
            model_name='translationkey',
            name='namespace',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='namespace'),
        ),
        migrations.AddField(
            model_name='translationkey',
            name='public',
            field=models.BooleanField(default=True),
        ),
    ]
