# Generated by Django 2.0.4 on 2018-12-13 12:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tradukoj', '0009_auto_20181213_1239'),
    ]

    operations = [
        migrations.RenameField(
            model_name='translationkey',
            old_name='new_namespace',
            new_name='namespace',
        ),
    ]
