# Generated by Django 2.0.4 on 2018-12-19 18:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tradukoj', '0011_auto_20181213_1322'),
    ]

    operations = [
        migrations.AlterField(
            model_name='gettextfile',
            name='log',
            field=models.TextField(blank=True, max_length=1024, null=True, verbose_name='Log'),
        ),
        migrations.AlterUniqueTogether(
            name='translation',
            unique_together={('key', 'bcp47')},
        ),
    ]
